// src/StoryPage.js
import { useEffect, useState } from 'react';
import '../css/global.css';
import { fetchYamlData } from './components/fetchYamlData';

function StoryPage() {
  const [data, setData] = useState(null);
  const [error, setError] = useState(null);
  const [currentStep, setCurrentStep] = useState(0);

  useEffect(() => {
    const loadData = async () => {
      try {
        const parsedData = await fetchYamlData({ src: '/yml/DialogPorsche.yml' });
        console.log("Parsed in component:", parsedData);
        if (!Array.isArray(parsedData)) {
          throw new Error('YAML data is not an array');
        }
        setData(parsedData);
      } catch (error) {
        setError(error.message);
      }
    };
    loadData();
  }, []);
  

  if (error) {
    return <div>Error loading YAML data: {error}</div>;
  }

  if (!data) {
    return <div>Loading...</div>;
  }

  const handleClicked = () => {
    console.log(data);
    // You can add logic here to handle the click event, such as navigating to the next step
    if (currentStep < data.length - 1) {
      setCurrentStep(currentStep + 1);
    }
  };

  const currentStepData = data[currentStep];

  return (
    <div
      onClick={handleClicked}
      style={{
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        height: '100vh',
        flexDirection: 'column',
      }}
    >
      <label className='title'>Fifty Shades <br /> of Bully</label>
      <div>
        <p>ID: {currentStepData.id}</p>
        <p>Type: {currentStepData.type}</p>
        {currentStepData.name && <p>Name: {currentStepData.name}</p>}
        <p>Text: {currentStepData.text}</p>
        {currentStepData.option && (
          <ul>
            {currentStepData.option.map((option, index) => (
              <li key={index}>{option.text}</li>
            ))}
          </ul>
        )}
      </div>
    </div>
  );
}

export default StoryPage;
